﻿''' <summary>
''' Contains information about a remote host.
''' </summary>
Public Structure HostInfo

    ''' <summary>
    ''' The name of the remote host.
    ''' </summary>
    Private ReadOnly _hostName As String
    ''' <summary>
    ''' The port number of the remote host.
    ''' </summary>
    Private ReadOnly _port As Integer


    ''' <summary>
    ''' Gets the name of the remote host.
    ''' </summary>
    ''' <value>
    ''' A <b>String</b> containing a host name.
    ''' </value>
    Public ReadOnly Property HostName() As String
        Get
            Return Me._hostName
        End Get
    End Property

    ''' <summary>
    ''' Gets the port number of the remote host.
    ''' </summary>
    ''' <value>
    ''' An <b>Int32</b> containing a port number.
    ''' </value>
    Public ReadOnly Property Port() As Integer
        Get
            Return _port
        End Get
    End Property


    ''' <summary>
    ''' Creates a new instance of the <see cref="HostInfo" /> class.
    ''' </summary>
    ''' <param name="hostName">
    ''' The name of the remote host.
    ''' </param>
    ''' <param name="port">
    ''' The port number of the remote host.
    ''' </param>
    Public Sub New(ByVal hostName As String, ByVal port As Integer)
        Me._hostName = hostName
        Me._port = port
    End Sub


    ''' <summary>
    ''' Compares the current instance to another object for value equality.
    ''' </summary>
    ''' <param name="host">
    ''' The object to which the current instance is compared.
    ''' </param>
    ''' <returns>
    ''' <b>true</b> if both the host name and port of both instances are the same; otherwise, <b>False</b>.
    ''' </returns>
    ''' <remarks>
    ''' The comparison of host names is case-insensitive.
    ''' </remarks>
    Public Overloads Function Equals(ByVal host As HostInfo) As Boolean
        Return Me.HostName.Equals(host.HostName, StringComparison.CurrentCultureIgnoreCase) AndAlso _
               Me.Port = host.Port
    End Function

    ''' <summary>
    ''' Overridden.  Compares the current instance to another object for value equality.
    ''' </summary>
    ''' <param name="obj">
    ''' The object to which the current instance is compared.
    ''' </param>
    ''' <returns>
    ''' <b>true</b> if <i>obj</i> is a <see cref="HostInfo" /> value and both the host name and port of both instances are the same; otherwise, <b>False</b>.
    ''' </returns>
    ''' <remarks>
    ''' The comparison of host names is case-insensitive.
    ''' </remarks>
    Public Overloads Overrides Function Equals(ByVal obj As Object) As Boolean
        Return TypeOf obj Is HostInfo AndAlso _
               Me.Equals(DirectCast(obj, HostInfo))
    End Function

    ''' <summary>
    ''' Overridden.  Returns a string representation of the <see cref="HostInfo" /> object.
    ''' </summary>
    ''' <returns>
    ''' A <b>String</b> containing the host name and port number, separated by a colon.
    ''' </returns>
    Public Overrides Function ToString() As String
        Return Me._hostName & ":" & Me._port
    End Function

End Structure
